Releases
========

0.0.7 (2013-08-29)
------------------

* Russian translations
* Thanks to:
    * `Armicron <https://github.com/armicron>`_


0.0.6  (2013-08-22)
-------------------

* Python3 support
* Polish translation
* Thanks to:
    * `Michał Pasternak <https://github.com/mpasternak>`_

0.0.5  (2013-07-03)
-------------------

* Improvements in the README
* Exportable to XLS with `xlwt <http://pypi.python.org/pypi/xlwt/>`_
* Thanks to:
    * `Crashy23 <https://github.com/Crashy23>`_
    * `Gamesbook <https://github.com/gamesbook>`_
    * And spatially to `Austin Phillips <https://github.com/austinphillips2>`_


0.0.4  (2013-05-17)
-------------------

* Escape csv data correctly during output
* The fields with commas now are not split into multiple columns
* Thanks to:
    * `Austin Phillips <https://github.com/austinphillips2>`_

0.0.3  (2012-07-19)
-------------------

* Fix a little error, when a column has line breaks. Now these are changed to espaces
* Details

0.0.2  (2012-07-18)
-------------------

* Add a default view (https://docs.djangoproject.com/en/dev/topics/class-based-views/)
* Exportable to XLS
* Update the README

0.0.1  (2012-07-17)
-------------------

* Initial release
